package domande;

import java.io.StringWriter;
import org.w3c.dom.*;

import domande.dati.Domanda;
import domande.dati.PollDb;

import javax.xml.parsers.*;
import javax.xml.transform.OutputKeys;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;

/**
 * Genera ed importa file xml per le domande
 * @author Giuseppe
 *
 */
public class XMLWriter {
	private Document out;

	public XMLWriter(PollDb poll) {
		try {
			DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
			DocumentBuilder builder = factory.newDocumentBuilder();
			this.out = builder.newDocument();
			this.out = creaStrutturaDocumento(out, poll);
		} catch(Exception ex) {
			ex.printStackTrace();		
		} 
	}

	public Document creaStrutturaDocumento(Document doc, PollDb poll) {
		Element sondaggio = doc.createElement("sondaggio");
		Element titoloPoll = creaTag(doc, "titoloPoll", poll.getTitle());

		Element domande = doc.createElement("domande");
		//inserisco le domande
		for(Domanda d : poll.getDomande())
			domande.appendChild(creaDomanda(doc, d));

		//creo la struttura
		sondaggio.appendChild(titoloPoll);
		sondaggio.appendChild(domande);
		doc.appendChild(sondaggio);
		doc.normalize();
		return doc;
	}

	public Element creaDomanda(Document doc, Domanda d) {
		Element risposta3=null, risposta4=null;

		Element domanda = doc.createElement("domanda");
		Element titoloDomanda = creaTag(doc, "titoloDomanda", d.getDomanda());
		Element risposta1 = creaTag(doc, "risposta", d.getRisp1());
		risposta1.setAttribute("num", new String(""+d.getNumRisp1()));
		Element risposta2 = creaTag(doc, "risposta", d.getRisp2());
		risposta2.setAttribute("num", new String(""+d.getNumRisp2()));
		if(d.isAttRisp3()) {
			risposta3 = creaTag(doc, "risposta", d.getRisp3());
			risposta3.setAttribute("num", new String(""+d.getNumRisp3()));

			if(d.isAttRisp4()) {
				risposta4 = creaTag(doc, "risposta", d.getRisp4());
				risposta3.setAttribute("num", new String(""+d.getNumRisp4()));
			}
		}
		domanda.appendChild(titoloDomanda);
		domanda.appendChild(risposta1);
		domanda.appendChild(risposta2);
		if(risposta3 != null) {
			domanda.appendChild(risposta3);
			if(risposta4 != null) {
				domanda.appendChild(risposta4);
			}
		}
		return domanda;		
	}

	private Element creaTag(Document doc, String tagName, String text) {
		Element nodo = doc.createElement(tagName);
		Text testo = doc.createTextNode(text);
		nodo.appendChild(testo);
		return nodo;
	}

	public String getXML() {
		try {
			TransformerFactory transfac = TransformerFactory.newInstance();
			Transformer trans = transfac.newTransformer();
			trans.setOutputProperty(OutputKeys.OMIT_XML_DECLARATION, "no");
			trans.setOutputProperty(OutputKeys.STANDALONE, "yes");
			trans.setOutputProperty(OutputKeys.INDENT, "yes");

			//create string from xml tree
			StringWriter sw = new StringWriter();
			StreamResult result = new StreamResult(sw);
			DOMSource source = new DOMSource(this.out);
			trans.transform(source, result);
			String xmlString = sw.toString();

			return xmlString;
		} catch(Exception ex) {
			ex.printStackTrace();
		}
		return null;
	}


}
